# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_analytics/v1/tick_vwap.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/tick_analytics/v1/tick_vwap.proto',
  package='systemathics.apis.services.tick_analytics.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n<systemathics/apis/services/tick_analytics/v1/tick_vwap.proto\x12,systemathics.apis.services.tick_analytics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xa1\x02\n\x0fTickVwapRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12)\n\x06period\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12)\n\x06offset\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x12\n\nadjustment\x18\x05 \x01(\x08\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x06 \x03(\t\x12\x0e\n\x06reject\x18\x07 \x03(\t\"~\n\x10TickVwapResponse\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04vwap\x18\x02 \x01(\x01\x12\r\n\x05trade\x18\x03 \x01(\x01\x12\x0e\n\x06volume\x18\x04 \x01(\x03\x12\r\n\x05ticks\x18\x05 \x01(\x05\x32\x9f\x01\n\x0fTickVwapService\x12\x8b\x01\n\x08TickVwap\x12=.systemathics.apis.services.tick_analytics.v1.TickVwapRequest\x1a>.systemathics.apis.services.tick_analytics.v1.TickVwapResponse0\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,])




_TICKVWAPREQUEST = _descriptor.Descriptor(
  name='TickVwapRequest',
  full_name='systemathics.apis.services.tick_analytics.v1.TickVwapRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.tick_analytics.v1.TickVwapRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.tick_analytics.v1.TickVwapRequest.constraints', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='period', full_name='systemathics.apis.services.tick_analytics.v1.TickVwapRequest.period', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='systemathics.apis.services.tick_analytics.v1.TickVwapRequest.offset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adjustment', full_name='systemathics.apis.services.tick_analytics.v1.TickVwapRequest.adjustment', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accept', full_name='systemathics.apis.services.tick_analytics.v1.TickVwapRequest.accept', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reject', full_name='systemathics.apis.services.tick_analytics.v1.TickVwapRequest.reject', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=279,
  serialized_end=568,
)


_TICKVWAPRESPONSE = _descriptor.Descriptor(
  name='TickVwapResponse',
  full_name='systemathics.apis.services.tick_analytics.v1.TickVwapResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='systemathics.apis.services.tick_analytics.v1.TickVwapResponse.time_stamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vwap', full_name='systemathics.apis.services.tick_analytics.v1.TickVwapResponse.vwap', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trade', full_name='systemathics.apis.services.tick_analytics.v1.TickVwapResponse.trade', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='systemathics.apis.services.tick_analytics.v1.TickVwapResponse.volume', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticks', full_name='systemathics.apis.services.tick_analytics.v1.TickVwapResponse.ticks', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=570,
  serialized_end=696,
)

_TICKVWAPREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_TICKVWAPREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_TICKVWAPREQUEST.fields_by_name['period'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TICKVWAPREQUEST.fields_by_name['offset'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TICKVWAPRESPONSE.fields_by_name['time_stamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['TickVwapRequest'] = _TICKVWAPREQUEST
DESCRIPTOR.message_types_by_name['TickVwapResponse'] = _TICKVWAPRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TickVwapRequest = _reflection.GeneratedProtocolMessageType('TickVwapRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKVWAPREQUEST,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_vwap_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickVwapRequest)
  })
_sym_db.RegisterMessage(TickVwapRequest)

TickVwapResponse = _reflection.GeneratedProtocolMessageType('TickVwapResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKVWAPRESPONSE,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_vwap_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickVwapResponse)
  })
_sym_db.RegisterMessage(TickVwapResponse)



_TICKVWAPSERVICE = _descriptor.ServiceDescriptor(
  name='TickVwapService',
  full_name='systemathics.apis.services.tick_analytics.v1.TickVwapService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=699,
  serialized_end=858,
  methods=[
  _descriptor.MethodDescriptor(
    name='TickVwap',
    full_name='systemathics.apis.services.tick_analytics.v1.TickVwapService.TickVwap',
    index=0,
    containing_service=None,
    input_type=_TICKVWAPREQUEST,
    output_type=_TICKVWAPRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TICKVWAPSERVICE)

DESCRIPTOR.services_by_name['TickVwapService'] = _TICKVWAPSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from systemathics.apis.services.static_data.v1 import static_data_pb2 as systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_static__data__pb2


class StaticDataServiceStub(object):
    """Called to request reference data.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StaticData = channel.unary_unary(
                '/systemathics.apis.services.static_data.v1.StaticDataService/StaticData',
                request_serializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_static__data__pb2.StaticDataRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_static__data__pb2.StaticDataResponse.FromString,
                )


class StaticDataServiceServicer(object):
    """Called to request reference data.
    """

    def StaticData(self, request, context):
        """Gets reference data
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StaticDataServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StaticData': grpc.unary_unary_rpc_method_handler(
                    servicer.StaticData,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_static__data__pb2.StaticDataRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_static__data__pb2.StaticDataResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'systemathics.apis.services.static_data.v1.StaticDataService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class StaticDataService(object):
    """Called to request reference data.
    """

    @staticmethod
    def StaticData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.static_data.v1.StaticDataService/StaticData',
            systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_static__data__pb2.StaticDataRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_static__data_dot_v1_dot_static__data__pb2.StaticDataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
